@@ -1,6 +1,6 @@
 loss.grpreg <- grpreg:::loss.grpreg
 
-.test = "logLik is correct"
+# logLik is correct
 n <- 50
 group <- rep(0:4,5:1)
 p <- length(group)
@@ -9,33 +9,33 @@ y <- rnorm(n)
 yy <- runif(n) > .5
 fit.mle <- lm(y~X)
 fit <- grpreg(X, y, group, penalty="grLasso", lambda.min=0)
-check(logLik(fit)[100], logLik(fit.mle)[1], tol=.001)
-check(apply(loss.grpreg(y, predict(fit, X=X, type='response'), family='gaussian'), 2, sum), fit$loss)
-check(AIC(fit)[100], AIC(fit.mle), tol=.001)
+expect_equivalent(logLik(fit)[100], logLik(fit.mle)[1], tol=.001)
+expect_equivalent(apply(loss.grpreg(y, predict(fit, X=X, type='response'), family='gaussian'), 2, sum), fit$loss)
+expect_equivalent(AIC(fit)[100], AIC(fit.mle), tol=.001)
 fit <- grpreg(X, y, group, penalty="gel", lambda.min=0)
-check(logLik(fit)[100], logLik(fit.mle)[1], tol=.001)
-check(apply(loss.grpreg(y, predict(fit, X=X, type='response'), family='gaussian'), 2, sum), fit$loss, tol=0.0001)
-check(AIC(fit)[100], AIC(fit.mle), tol=.001)
+expect_equivalent(logLik(fit)[100], logLik(fit.mle)[1], tol=.001)
+expect_equivalent(apply(loss.grpreg(y, predict(fit, X=X, type='response'), family='gaussian'), 2, sum), fit$loss, tol=0.0001)
+expect_equivalent(AIC(fit)[100], AIC(fit.mle), tol=.001)
 fit.mle <- glm(yy~X, family="binomial")
 fit <- grpreg(X, yy, group, penalty="grLasso", lambda.min=0, family="binomial")
-check(logLik(fit)[100], logLik(fit.mle)[1], tol=.001)
-check(apply(loss.grpreg(yy, predict(fit, X=X, type='response'), family='binomial'), 2, sum), fit$loss, tol=0.0001)
-check(AIC(fit)[100], AIC(fit.mle), tol=.001)
+expect_equivalent(logLik(fit)[100], logLik(fit.mle)[1], tol=.001)
+expect_equivalent(apply(loss.grpreg(yy, predict(fit, X=X, type='response'), family='binomial'), 2, sum), fit$loss, tol=0.0001)
+expect_equivalent(AIC(fit)[100], AIC(fit.mle), tol=.001)
 fit <- grpreg(X, yy, group, penalty="gel", lambda.min=0, family="binomial")
-check(logLik(fit)[100], logLik(fit.mle)[1], tol=.001)
-check(apply(loss.grpreg(yy, predict(fit, X=X, type='response'), family='binomial'), 2, sum), fit$loss, tol=0.0001)
-check(AIC(fit)[100], AIC(fit.mle), tol=.001)
+expect_equivalent(logLik(fit)[100], logLik(fit.mle)[1], tol=.001)
+expect_equivalent(apply(loss.grpreg(yy, predict(fit, X=X, type='response'), family='binomial'), 2, sum), fit$loss, tol=0.0001)
+expect_equivalent(AIC(fit)[100], AIC(fit.mle), tol=.001)
 fit.mle <- glm(yy~X, family="poisson")
 fit <- grpreg(X, yy, group, penalty="grLasso", lambda.min=0, family="poisson")
-check(logLik(fit)[100], logLik(fit.mle)[1], tol=.001)
-check(apply(loss.grpreg(yy, predict(fit, X=X, type='response'), family='poisson'), 2, sum), fit$loss, tol=0.0001)
-check(AIC(fit)[100], AIC(fit.mle), tol=.001)
+expect_equivalent(logLik(fit)[100], logLik(fit.mle)[1], tol=.001)
+expect_equivalent(apply(loss.grpreg(yy, predict(fit, X=X, type='response'), family='poisson'), 2, sum), fit$loss, tol=0.0001)
+expect_equivalent(AIC(fit)[100], AIC(fit.mle), tol=.001)
 fit <- grpreg(X, yy, group, penalty="gel", lambda.min=0, family="poisson")
-check(logLik(fit)[100], logLik(fit.mle)[1], tol=.001)
-check(apply(loss.grpreg(yy, predict(fit, X=X, type='response'), family='poisson'), 2, sum), fit$loss, tol=0.0001)
-check(AIC(fit)[100], AIC(fit.mle), tol=.001)
+expect_equivalent(logLik(fit)[100], logLik(fit.mle)[1], tol=.001)
+expect_equivalent(apply(loss.grpreg(yy, predict(fit, X=X, type='response'), family='poisson'), 2, sum), fit$loss, tol=0.0001)
+expect_equivalent(AIC(fit)[100], AIC(fit.mle), tol=.001)
 
-.test = "grpreg handles user-specified lambda"
+# grpreg handles user-specified lambda
 n <- 50
 group <- rep(0:3,4:1)
 p <- length(group)
@@ -44,18 +44,18 @@ y <- rnorm(n)
 yy <- y > 0
 fit1 <- grpreg(X, y, group, penalty="grLasso")
 fit2 <- grpreg(X, y, group, penalty="grLasso", lambda=fit1$lambda)
-check(fit1$beta, fit2$beta)
+expect_equivalent(fit1$beta, fit2$beta)
 fit1 <- grpreg(X, y, group, penalty="gel")
 fit2 <- grpreg(X, y, group, penalty="gel", lambda=fit1$lambda)
-check(fit1$beta, fit2$beta)
+expect_equivalent(fit1$beta, fit2$beta)
 fit1 <- grpreg(X, yy, group, penalty="grLasso", family="binomial")
 fit2 <- grpreg(X, yy, group, penalty="grLasso", family="binomial", lambda=fit1$lambda)
-check(fit1$beta, fit2$beta)
+expect_equivalent(fit1$beta, fit2$beta)
 fit1 <- grpreg(X, yy, group, penalty="gel", family="binomial")
 fit2 <- grpreg(X, yy, group, penalty="gel", family="binomial", lambda=fit1$lambda)
-check(fit1$beta, fit2$beta)
+expect_equivalent(fit1$beta, fit2$beta)
 
-.test = "grpreg named groups"
+# grpreg named groups
 n <- 50
 group1 <- rep(0:3,4:1)
 group2 <- rep(c("0", "A", "B", "C"), 4:1)
@@ -66,10 +66,10 @@ y <- rnorm(n)
 yy <- y > 0
 fit1 <- grpreg(X, y, group1, penalty="grLasso")
 fit2 <- grpreg(X, y, group2, penalty="grLasso")
-check(coef(fit1), coef(fit2), tol=0.001)
+expect_equivalent(coef(fit1), coef(fit2), tol=0.001)
 cvfit <- cv.grpreg(X, y, group, penalty="grLasso")
 
-.test = "group.multiplier works"
+# group.multiplier works
 n <- 50
 p <- 11
 X <- matrix(rnorm(n*p),ncol=p)
@@ -83,7 +83,7 @@ plot(fit <- grpreg(X, y, group, penalty="grMCP", lambda.min=0, group.multiplier=
 plot(fit <- grpreg(X, y, group, penalty="grSCAD", lambda.min=0, group.multiplier=gm), main=fit$penalty)
 cvfit <- cv.grpreg(X, y, group, penalty="grLasso", group.multiplier=gm)
 
-.test = "dfmax works"
+# dfmax works
 n <- 100
 group <- rep(1:10, rep(3,10))
 p <- length(group)
@@ -93,37 +93,36 @@ yy <- runif(n) > .5
 dfmax <- 21
 fit <- grpreg(X, y, group, penalty="grLasso", lambda.min=0, dfmax=dfmax)
 nv <- sapply(predict(fit, type="vars"), length)
-check(max(head(nv, length(nv)-1)) <= dfmax)
-check(max(nv) > 3)
+expect_true(max(head(nv, length(nv)-1)) <= dfmax)
+expect_true(max(nv) > 3)
 fit <- grpreg(X, y, group, penalty="gel", lambda.min=0, dfmax=dfmax)
 nv <- sapply(predict(fit, type="vars"), length)
-check(max(head(nv, length(nv)-1)) <= dfmax)
-check(max(nv) > 3)
+expect_true(max(head(nv, length(nv)-1)) <= dfmax)
+expect_true(max(nv) > 3)
 fit <- grpreg(X, yy, group, penalty="grLasso", family="binomial", lambda.min=0, dfmax=dfmax)
 nv <- sapply(predict(fit, type="vars"), length)
-check(max(head(nv, length(nv)-1)) <= dfmax)
-check(max(nv) > 3)
+expect_true(max(head(nv, length(nv)-1)) <= dfmax)
+expect_true(max(nv) > 3)
 fit <- grpreg(X, yy, group, penalty="gel", family="binomial", lambda.min=0, dfmax=dfmax)
 nv <- sapply(predict(fit, type="vars"), length)
-check(max(head(nv, length(nv)-1)) <= dfmax)
-check(max(nv) > 3)
+expect_true(max(head(nv, length(nv)-1)) <= dfmax)
+expect_true(max(nv) > 3)
 
-.test = "gmax works"
+# gmax works
 gmax <- 7
 fit <- grpreg(X, y, group, penalty="grLasso", lambda.min=0, gmax=gmax)
 ng <- sapply(predict(fit, type="groups"), length)
-check(max(head(ng, length(ng)-1)) <= gmax)
-check(max(ng) > 2)
+expect_true(max(head(ng, length(ng)-1)) <= gmax)
+expect_true(max(ng) > 2)
 fit <- grpreg(X, y, group, penalty="gel", lambda.min=0, gmax=gmax)
 ng <- sapply(predict(fit, type="groups"), length)
-check(max(head(ng, length(ng)-1)) <= gmax)
-check(max(ng) > 2)
+expect_true(max(head(ng, length(ng)-1)) <= gmax)
+expect_true(max(ng) > 2)
 fit <- grpreg(X, yy, group, penalty="grLasso", family="binomial", lambda.min=0, gmax=gmax)
 ng <- sapply(predict(fit, type="groups"), length)
-check(max(head(ng, length(ng)-1)) <= gmax)
-check(max(ng) > 2)
+expect_true(max(head(ng, length(ng)-1)) <= gmax)
+expect_true(max(ng) > 2)
 fit <- grpreg(X, yy, group, penalty="gel", family="binomial", lambda.min=0, gmax=gmax)
 ng <- sapply(predict(fit, type="groups"), length)
-check(max(head(ng, length(ng)-1)) <= gmax)
-check(max(ng) > 2)
-
+expect_true(max(head(ng, length(ng)-1)) <= gmax)
+expect_true(max(ng) > 2)
